==> koffice-1.2.1.tar.bz2: koffice-1.2.1/filters/kword/latex/export/document.h <==
/*
** Header file for inclusion with kword_xml2latex.c
**
** Copyright (C) 2000 Robert JACOLIN
**
** This library is free software; you can redistribute it and/or
** modify it under the terms of the GNU Library General Public
** License as published by the Free Software Foundation; either
** version 2 of the License, or (at your option) any later version.
**
** This library is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
** Library General Public License for more details.
**
** To receive a copy of the GNU Library General Public License, write to the
** Free Software Foundation, Inc., 59 Temple Place - Suite 330,
** Boston, MA  02111-1307, USA.
**
*/

#ifndef __KWORD_DOCUMENT_H__
#define __KWORD_DOCUMENT_H__

#include <qptrlist.h>
#include <qtextstream.h>

#include "listtable.h"		/* list of tables (another kind of list of elements). */
#include "config.h"
//#include "pixmap.h"

enum EGenerate
{
	E_LATEX,
	E_KWORD,
	E_CONFIG
};

/***********************************************************************/
/* Class: Document                                                     */
/***********************************************************************/

/**
 * This class hold a whole document with its headers, footers, footnotes, endnotes,
 * content, ... It can generate a latex file.
 */
class Document: public XmlParser, Config
{

	QPtrList<Element> _headers;
	QPtrList<Element> _footers;
	QPtrList<Element> _footnotes;
	QPtrList<Element> _formulas;
	QPtrList<Element> _corps;
	QPtrList<Element> _pixmaps;

	ListTable      _tables;
	//QPtrList<Element> _parts;
	EGenerate     _generation;

	public:
		/**
		 * Constructor
		 *
		 * Creates a new instance of Document.
		 */
		Document();

		/**
		 * Destructor
		 *
		 * Remove the list of headers, footers and the body.
		 */
		virtual ~Document();

		/**
		 * Accessors
		 */

		/**
		 * @return the next frame type (header, footer, body, footnote).
		 */
		SType getTypeFrameset(const QDomNode);
		//FileHeader* getFileHeader() const { return _fileHeader; }
		//void setFileHeader(FileHeader *h) { _fileHeader = h; }

		void analyse(const QDomNode);
		void analysePixmaps(const QDomNode);

		void generate(QTextStream&, bool);
		Element* searchAnchor(QString);
		Element* searchFootnote(QString);
		//Pixmap*  searchPixmap(QString);

	private:
		/**
		 * Generate the second part of the preambule
		 */
		void generatePreambule(QTextStream&);

		/**
		 * Generate the header
		 */
		void  generateTypeHeader(QTextStream&, Element*);
		/**
		 * Generate the footer
		 */
		void  generateTypeFooter(QTextStream&, Element*);
};

#endif /* __KWORD_DOCUMENT_H__ */

==> koffice-1.3.5.tar.bz2: koffice-1.3.5/filters/kword/latex/export/document.h <==
/*
** Header file for inclusion with kword_xml2latex.c
**
** Copyright (C) 2000-2002 Robert JACOLIN
**
** This library is free software; you can redistribute it and/or
** modify it under the terms of the GNU Library General Public
** License as published by the Free Software Foundation; either
** version 2 of the License, or (at your option) any later version.
**
** This library is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
** Library General Public License for more details.
**
** To receive a copy of the GNU Library General Public License, write to the
** Free Software Foundation, Inc., 59 Temple Place - Suite 330,
** Boston, MA  02111-1307, USA.
**
*/

#ifndef __KWORD_LATEX_DOCUMENT_H__
#define __KWORD_LATEX_DOCUMENT_H__

#include <qptrlist.h>
#include <qtextstream.h>

#include "listtable.h"		/* list of tables (another kind of list of elements). */
#include "key.h"


/***********************************************************************/
/* Class: Document                                                     */
/***********************************************************************/

/**
 * This class hold a whole document with its headers, footers, footnotes, endnotes,
 * content, ... It can generate a latex file.
 */
class Document: public XmlParser
{
	public:
		enum EGenerate { E_LATEX, E_KWORD, E_CONFIG };

	private:
		QPtrList<Element> _headers;
		QPtrList<Element> _footers;
		QPtrList<Element> _footnotes;
		QPtrList<Element> _formulas;
		QPtrList<Element> _corps;
		QPtrList<Element> _pixmaps;
		QPtrList<Key> _keys;

		ListTable      _tables;
		//QPtrList<Element> _parts;
		EGenerate     _generation;

	public:
		/**
		 * Constructor
		 *
		 * Creates a new instance of Document.
		 */
		Document();

		/**
		 * Destructor
		 *
		 * Remove the list of headers, footers and the body.
		 */
		virtual ~Document();

		/**
		 * Accessors
		 */

		/**
		 * @return the next frame type (header, footer, body, footnote).
		 */
		SType getTypeFrameset(const QDomNode);
		//FileHeader* getFileHeader() const { return _fileHeader; }
		//void setFileHeader(FileHeader *h) { _fileHeader = h; }

		void analyse(const QDomNode);
		void analysePixmaps(const QDomNode);

		void generate(QTextStream&, bool);
		Element* searchAnchor(QString);
		Element* searchFootnote(QString);
		Key* searchKey(QString keyName);
		/** Save the file in a temp file. */
		QString extractData(QString key);
		/** Build a DOM tree (e.g. a KOffice part) */
		//QDomNode extractKoData(QString key);
		//Pixmap*  searchPixmap(QString);

	private:
		/**
		 * Generate the second part of the preambule
		 */
		void generatePreambule(QTextStream&);

		/**
		 * Generate the header
		 */
		void  generateTypeHeader(QTextStream&, Element*);
		/**
		 * Generate the footer
		 */
		void  generateTypeFooter(QTextStream&, Element*);
};

#endif /* __KWORD_LATEX_DOCUMENT_H__ */
